#' Plots visual field
#'
#' \code{plotvf} plots a figure of a visual field matrix with sensitivity threshold values
#' @param xs A vector of horizontal coordinates. The length of it must be either 10 for a monocular or 25 for a binocular visual field plot.
#' @param vf A matrix of either a left/right monocular visual field or a binocular visual field sensitivity values
#' @param title A string for the name of the plot.
#' @return A plot of a monocular or binocular visual field.
#' @importFrom graphics axis box par plot points segments text
#' @importFrom utils head tail
#' @examples
#' m_xs <- seq(-27, 27, length.out = 10)
#' rghtvf <- matrix(c(
#' NA, NA, NA, 30, 30, 30, 30, NA, NA, NA,
#' NA, NA, 30, 30, 30, 30, 30, 30, NA, NA,
#' NA, 30, 30, 30, 30, 30, 30, 30, 30, NA,
#' 30, 30, 30, 30, 30, 30, 30, 30, 30, NA,
#' 30, 30, 30, 30, 30, 30, 30,  0, 30, NA,
#' NA, 30, 30, 30, 30, 30, 30, 30, 30, NA,
#' NA, NA, 30, 30, 30, 30, 30, 30, NA, NA,
#' NA, NA, NA, 30, 30, 30, 30, NA, NA, NA
#' ), ncol=10, byrow=TRUE)
#' plotvf(m_xs, rghtvf, title='right visual field')
#' @section Warning:
#' the length of xs and the number of columns of the vf must be the same and with a value of either 10 or 25.
#' @export
plotvf <- function(xs, vf, title = "") {
    if (getOption("warn") > 0) {
        stopifnot(length(xs) %in% c(10, 20),
                  ncol(vf) %in% c(10, 20),
                  length(xs) == ncol(vf))
    }
    p <- par()$mar
    par(mar = c(2, 2, 2, 2))
    plot(0, 0, ylim = c(-22, 22), xlim = range(xs), type = "n", main = title)
    ys = seq(21, -21, -6)
    n <- length(xs)
    y <- head(ys, 1)
    for (i in 1:nrow(vf)) {
        for (j in 1:ncol(vf)) {
            if (!is.na(vf[i, j]))
                points(xs[j], y,
                       pch = 22,
                       cex = 5,
                       col = NA,
                       bg = c(colfunc(35), tail(colfunc(35), 1), tail(colfunc(35),1))[vf[i, j] + 1])
        }
        text(xs, rep(y, n), round(vf[i, ]), cex = 1, col = sapply(vf[i, ], get_inv_col))
        y <- y - 6
    }
    box()
    on.exit(par(mar = p))
}
